==> entity_media_usage-1.0.3.tar.gz: entity_media_usage/src/Form/EntityMediaUsageSettingsForm.php <==
<?php

namespace Drupal\entity_media_usage\Form;

use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for entity_media_usage settings.
 */
class EntityMediaUsageSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_media_usage_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['entity_media_usage.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_media_usage.settings');

    $entity_types = \Drupal::entityTypeManager()->getDefinitions();
    $entity_types = array_filter($entity_types, function (EntityTypeInterface $entity_type) {
      return $entity_type instanceof ContentEntityTypeInterface;
    });

    $form['entity_type_ids'] = [
      '#type'          => 'checkboxes',
      '#title'         => $this->t('Referenced entity types'),
      '#description'   => $this->t('Select which referenced entity types to show in Media Usage.'),
      '#options'       => array_combine(array_keys($entity_types), array_keys($entity_types)),
      '#default_value' => $config->get('entity_type_ids') ?? ['media' => 'media'],
    ];

    $views = \Drupal::entityTypeManager()->getStorage('view')->loadMultiple();

    $form['media_usage_view'] = [
      '#type'        => 'details',
      '#title'       => $this->t('View'),
      '#description' => $this->t('Select a custom View to display referenced entities in Media Usage.'),
      '#open'        => TRUE,
    ];
    foreach ($entity_types as $entity_type) {
      $form['media_usage_view'][$entity_type->id() . '_media_usage_view'] = [
        '#type'          => 'select',
        '#empty_option' => $this->t('- Select -'),
        '#options'       => array_combine(array_keys($views), array_keys($views)),
        '#title'         => $entity_type->getSingularLabel(),
        '#default_value' => $config->get($entity_type->id() . '_media_usage_view'),
        '#states'        => [
          'visible' => [
            'input[name="entity_type_ids[' . $entity_type->id() . ']"]' => ['checked' => TRUE],
          ],
        ],
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $exclude = ['submit', 'form_build_id', 'form_token', 'form_id', 'op'];
    $config  = $this->config('entity_media_usage.settings');
    foreach ($form_state->getValues() as $key => $data) {
      if (!in_array($key, $exclude)) {
        $config->set($key, $data);
      }
    }
    $config->save();

    $this->messenger()->addStatus($this->t('Settings saved.'));

    parent::submitForm($form, $form_state);
  }

}

==> entity_media_usage-1.0.4.tar.gz: entity_media_usage/src/Form/EntityMediaUsageSettingsForm.php <==
<?php

namespace Drupal\entity_media_usage\Form;

use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for entity_media_usage settings.
 */
class EntityMediaUsageSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_media_usage_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['entity_media_usage.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_media_usage.settings');

    $entity_types = \Drupal::entityTypeManager()->getDefinitions();
    $entity_types = array_filter($entity_types, function (EntityTypeInterface $entity_type) {
      return $entity_type instanceof ContentEntityTypeInterface;
    });

    // Active on.
    $active_on_default_value   = $config->get('active_on') ?? (in_array('node', array_keys($entity_types)) ? ['node' => 'node'] : []);
    $form['active_on_details'] = [
      '#type'        => 'details',
      '#title'       => $this->t('Tab display'),
      '#description' => '<p>' . $this->t('Activate "Media Usage" tab on specific entity types.') . '</p>' .
      '<p>' . $this->t('Currently selected:&nbsp;<strong>@list</strong>', [
        '@list' => implode(', ', array_filter($active_on_default_value, function ($v) {return $v !== 0;})),
      ]) . '</p>',
      '#open'        => TRUE,
    ];
    $form['active_on_details']['active_on'] = [
      '#type'          => 'checkboxes',
      '#title'         => $this->t('Content entity types'),
      '#description'   => $this->t('Selected entity types will have a "Media Usage" tab in their local tasks.'),
      '#options'       => array_combine(array_keys($entity_types), array_keys($entity_types)),
      '#default_value' => $active_on_default_value,
    ];

    // Entity type IDs.
    $entity_type_ids_default_value   = $config->get('entity_type_ids') ?? ['media' => 'media'];
    $form['entity_type_ids_details'] = [
      '#type'        => 'details',
      '#title'       => $this->t('Referenced entity types display'),
      '#description' => '<p>' . $this->t('Select which entity types to displayed in the "Media Usage" tab.') . '</p>' .
      '<p>' . $this->t('Currently selected:&nbsp;<strong>@list</strong>', [
        '@list' => implode(', ', array_filter($entity_type_ids_default_value, function ($v) {return $v !== 0;})),
      ]) . '</p>',
      '#open'        => TRUE,
    ];
    $form['entity_type_ids_details']['entity_type_ids'] = [
      '#type'          => 'checkboxes',
      '#title'         => $this->t('Content entity types'),
      '#description'   => $this->t('Selected entity types will be shown in list.'),
      '#options'       => array_combine(array_keys($entity_types), array_keys($entity_types)),
      '#default_value' => $entity_type_ids_default_value,
    ];

    // Views.
    $views = \Drupal::entityTypeManager()->getStorage('view')->loadMultiple();

    $form['media_usage_view'] = [
      '#type'        => 'details',
      '#title'       => $this->t('View'),
      '#description' => $this->t('Select a custom View to display referenced entities in Media Usage.'),
      '#open'        => TRUE,
    ];
    foreach ($entity_types as $entity_type) {
      $form['media_usage_view'][$entity_type->id() . '_media_usage_view'] = [
        '#type'          => 'select',
        '#empty_option'  => $this->t('- Select -'),
        '#options'       => array_combine(array_keys($views), array_keys($views)),
        '#title'         => $entity_type->getSingularLabel(),
        '#default_value' => $config->get($entity_type->id() . '_media_usage_view'),
        '#states'        => [
          'visible' => [
            'input[name="entity_type_ids[' . $entity_type->id() . ']"]' => ['checked' => TRUE],
          ],
        ],
      ];
    }

    $form['#attached']['library'][] = 'entity_media_usage/form';

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $exclude = ['submit', 'form_build_id', 'form_token', 'form_id', 'op'];
    $config  = $this->config('entity_media_usage.settings');
    foreach ($form_state->getValues() as $key => $data) {
      if (!in_array($key, $exclude)) {
        $config->set($key, $data);
      }
    }
    $config->save();

    $this->messenger()->addStatus($this->t('Settings saved.'));

    parent::submitForm($form, $form_state);
  }

}
